=========
Changelog
=========

Version 0.3.1
=============

- Updating pyscaffold version to 

Version 0.3.0
=============

- New GriddedBase class
- Slight changes in the method names

Version 0.2.0
=============

- Support of ioclass keyword arguments
- Fix iteration inconsistency

Version 0.1
===========

- First developer release
